@@ -1,7 +1,9 @@
 package Sah::Schemas::Domain;
 
-our $DATE = '2018-12-19'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'Sah-Schemas-Domain'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to domain names
@@ -18,7 +20,7 @@ Sah::Schemas::Domain - Schemas related to domain names
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schemas::Domain (from Perl distribution Sah-Schemas-Domain), released on 2018-12-19.
+This document describes version 0.003 of Sah::Schemas::Domain (from Perl distribution Sah-Schemas-Domain), released on 2019-11-29.
 
 =head1 HOMEPAGE
 
@@ -48,7 +50,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
